@@ -85,8 +85,10 @@ impl<'a, I: Tokens> Parser<I> {
             expect!(p, "class");
 
             let ident = p.parse_maybe_opt_binding_ident()?;
-            if let Some(span) = ident.invalid_class_name() {
-                p.emit_err(span, SyntaxError::TS2414);
+            if p.input.syntax().typescript() {
+                if let Some(span) = ident.invalid_class_name() {
+                    p.emit_err(span, SyntaxError::TS2414);
+                }
             }
 
             let type_params = if p.input.syntax().typescript() {
@@ -341,7 +343,9 @@ impl<'a, I: Tokens> Parser<I> {
                         kind: MethodKind::Method,
                     },
                 );
-            } else if self.is_class_property(/* asi */ true) {
+            } else if self.is_class_property(/* asi */ true)
+                || (self.syntax().typescript() && is!(self, '?'))
+            {
                 // Property named `declare`
 
                 let key = Either::Right(PropName::Ident(Ident::new(
@@ -401,7 +405,9 @@ impl<'a, I: Tokens> Parser<I> {
                         kind: MethodKind::Method,
                     },
                 );
-            } else if self.is_class_property(/* asi */ true) {
+            } else if self.is_class_property(/* asi */ true)
+                || (self.syntax().typescript() && is!(self, '?'))
+            {
                 // Property named `static`
 
                 // Avoid to parse
@@ -1276,7 +1282,18 @@ trait IsInvalidClassName {
 impl IsInvalidClassName for Ident {
     fn invalid_class_name(&self) -> Option<Span> {
         match self.sym {
-            js_word!("any") => Some(self.span),
+            js_word!("string")
+            | js_word!("null")
+            | js_word!("number")
+            | js_word!("object")
+            | js_word!("any")
+            | js_word!("unknown")
+            | js_word!("boolean")
+            | js_word!("bigint")
+            | js_word!("symbol")
+            | js_word!("void")
+            | js_word!("never")
+            | js_word!("intrinsic") => Some(self.span),
             _ => None,
         }
     }
